@@ -36,7 +36,14 @@ def dict_to_cognito(attributes, attr_map=None):
         if value in attributes.keys():
             attributes[key] = attributes.pop(value)
 
-    return [{"Name": key, "Value": value} for key, value in attributes.items()]
+    def normalize(val):
+        if isinstance(val, bool):
+            return "true" if val else "false"
+        return val
+
+    return [
+        {"Name": key, "Value": normalize(value)} for key, value in attributes.items()
+    ]
 
 
 def camel_to_snake(camel_str):
@@ -607,7 +614,7 @@ class Cognito:
         Create a user using admin super privileges.
         :param username: User Pool username
         :param temporary_password: The temporary password to give the user.
-        Leave blank to make Cognito generate a temporary password for the user.
+        Pass None or omit this to make Cognito generate a temporary password for the user.
         :param additional_kwargs: Dictionary with request params, such as MessageAction.
         :param attr_map: Attribute map to Cognito's attributes
         :param kwargs: Additional User Pool attributes
@@ -615,11 +622,12 @@ class Cognito:
         """
         if additional_kwargs is None:
             additional_kwargs = {}
+        if temporary_password:
+            additional_kwargs["TemporaryPassword"] = temporary_password
         response = self.client.admin_create_user(
             UserPoolId=self.user_pool_id,
             Username=username,
             UserAttributes=dict_to_cognito(kwargs, attr_map),
-            TemporaryPassword=temporary_password,
             **additional_kwargs,
         )
         kwargs.update(username=username)
@@ -682,6 +690,8 @@ class Cognito:
         )
 
     def admin_reset_password(self, username, client_metadata=None):
+        if client_metadata is None:
+            client_metadata = {}
         self.client.admin_reset_user_password(
             UserPoolId=self.user_pool_id,
             Username=username,
@@ -850,7 +860,7 @@ class Cognito:
         """
         self.client.admin_disable_user(
             UserPoolId=self.user_pool_id,
-            Username=self.username,
+            Username=username,
         )
 
     def admin_create_identity_provider(
@@ -872,6 +882,30 @@ class Cognito:
             **kwargs,
         )
 
+    def admin_describe_identity_provider(self, pool_id, provider_name):
+        """
+        Updates an existing identity provider
+        :param pool_id: The user pool ID
+        :param provider_name: The identity provider name
+        :return: dict of identity provider
+        """
+        return self.client.describe_identity_provider(
+            UserPoolId=pool_id, ProviderName=provider_name
+        )
+
+    def admin_update_identity_provider(self, pool_id, provider_name, **kwargs):
+        """
+        Updates an existing identity provider
+        :param pool_id: The user pool ID
+        :param provider_name: The identity provider name
+        :return:
+        """
+        self.client.update_identity_provider(
+            UserPoolId=pool_id,
+            ProviderName=provider_name,
+            **kwargs,
+        )
+
     def describe_user_pool_client(self, pool_id: str, client_id: str):
         """
         Returns configuration information of a specified user pool app client
